@@ -12,7 +12,7 @@ import time
 
 from shutil import copyfile,rmtree
 from stat import * 
-from py3toolbox.text_tools import re_findall
+import  text_tools 
 
 
 ####################################################################################################
@@ -168,7 +168,7 @@ def rm_file(file_name = None, folder = None, regex_pattern=None) :
   if file_name is None and folder is not None and regex_pattern is not None:
     file_name = []
     for f in get_files(folder = folder, type='file'):
-      if len(re_findall(regex_pattern, f)) > 0:
+      if len(text_tools.e_findall(regex_pattern, f)) > 0:
         file_name.append(f)
     
   # perform file delete 
@@ -206,7 +206,7 @@ def write_log(file_name, text, is_new = False):
 def read_file(file_name, return_type='str'):
   if return_type == 'str' :
     #return codecs.open(file_name, 'r', 'utf8').read() -- codecs.open obsolete
-    return open(file_name, 'r', encoding='utf-8').read()
+    return open(file_name, 'r', encoding='utf-8', errors="ignore").read()
     
     
   if return_type == 'list' :
@@ -262,7 +262,6 @@ def check_type(full_path):
   
 ####################################################################################################  
   
-  
 def scan_fs_tree(folder, ext='', recursive=True, type='A'):
   
   for obj in os.scandir(folder):
