@@ -1,6 +1,8 @@
 import os
 import re
- 
+import fs_tools 
+
+
 def re_search (re_pattern , text) :
   m = re.search(re_pattern, text)
   if m :  return m.groups
@@ -27,8 +29,18 @@ def map_none(input=None):
   else:
     return ""
 
+def search_from_files(re_pattern, folder, ext='',  recursive=True) :
+  file_list = fs_tools.get_files(folder=folder, ext=ext,  recursive=recursive, type='F')
+  if len(file_list) == 0 : return None
   
-  
+  result = {}
+  for f in file_list:
+    f_text = fs_tools.read_file(f,return_type='str')
+    m = re_findall(re_pattern, f_text)
+    if len(m) > 0:  result[f] = m
+
+  return result
+
 if __name__ == "__main__":
   str1 = 'product/900/162-11292V02G01'
   a = re_search('([^\/]*)$',str1)
@@ -37,6 +49,8 @@ if __name__ == "__main__":
   b = re_findall ('ENC\((.*)\)', 'truststore.password=EaNC(/ndgPwyPzRc56sv7r0BkSbGip76SN7GVhQqeyOzmQ+Y=)')
 
   b = re_findall ("(weight\([^()]+\))" , "weight(course.title:health in 344) [PerFieldSimilarity], result of:")
-  print (b)
+  print (b[0])
   
+
+  #print (search_from_files('(\d+)', 'E:/Projects/github.old/py3toolbox'))
   pass  
\ No newline at end of file
